.. vim: set fileencoding=utf-8 :

.. _activities_troubleshooting:

Troubleshooting
---------------

You can run unit tests we have prepared like this (install pytest_ first):


.. code-block:: shell

  # use your package manager to install the package "pytest"
  # here, I examplify with "miniconda":
  (activities) $ conda install pytest
  (activities) $ pytest ./test.py
  ....
  
  tests.py ...........    

  ============== 11 passed in 12.60s ==============

In case of problems, please get in touch with us `by e-mail
<mailto:john.doe@example.com>`_.

.. include:: links.rst
